@@ -301,7 +301,7 @@ main() {
             cp ${TARGETDIR}/oplist/index.php ${TARGETDIR}/oplist/index.php_${GLATEMPTIMESTAMP}
         fi
     fi
-    
+
     # falls include/update.php bereits existiert --> Sicherung
     if [ -f  ${TARGETDIR}/oplist/include/update.php ]; then
         GLATEMPTIMESTAMP=`date +%Y_%m_%d-%H_%M_%S`
@@ -334,7 +334,7 @@ main() {
     if [ ${DEBUG} -eq 0 ]; then
         tar xfvz ${ZIPFILE}
     fi
-    
+
     # falls include/index_indiv.php nicht existiert --> Template umbenennen
     if [ ! -f  ${TARGETDIR}/oplist/include/index_indiv.php ]; then
         # wir benennen das Template um
@@ -343,6 +343,7 @@ main() {
             cp ${TARGETDIR}/oplist/include/index_indiv.php.template ${TARGETDIR}/oplist/include/index_indiv.php
         fi
     fi
+    chmod g+w,o+w ${TARGETDIR}/oplist/include/index_indiv.php
 
     # Rechte setzen
     echo "Recht <root:${GROUP}> für <oplist>"
@@ -383,6 +384,7 @@ main() {
             cp ${TARGETDIR}/oplist/conf/oplist.ini.template ${TARGETDIR}/oplist/conf/oplist.ini
         fi
     fi
+    chmod g+w,o+w ${TARGETDIR}/oplist/conf/oplist.ini
 
     # link in /u01/app/oplist erstellen (fuer einfacheres editieren)
     echo "Verlinke <index.php> und <oplist.ini> nach <${APPDIR}/oplist>"
